@@ -1,9 +1,21 @@
 import pygame
+import sys
+import os
+
+def resource_path(relative_path):
+    try:
+    # PyInstaller creates a temp folder and stores path in _MEIPASS
+        base_path = sys._MEIPASS
+    except Exception:
+        base_path = os.path.dirname(os.path.abspath(__file__))
+
+    return os.path.join(base_path, relative_path)
 
-ICON_FILE = "rsc/icon.png"
 WINDOW_NAME = "CHIPy8"
+ICON_FILE = resource_path("icon.png")
+FONT_FILE = resource_path("font.ch8")
+SOUND_FILE = resource_path("beep.mp3")
 
-FONT_FILE = "rsc/font.ch8"
 WAITING_TIME = 1
 INITIAL_PC = 0x200
 COSMAC_VIP = False
